netapp_ontap.models.svm_nfs API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.svm_nfs`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SvmNfsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SvmNfs object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `enabled GET POST PATCH`

    Enable NFS? Setting to true creates a service if not already created.

  `links GET`

    The links field of the svm_nfs.